import { shallowMount, createLocalVue } from "@vue/test-utils";
import Vue from "vue/dist/vue";
import Vuex from "vuex";
import PageLayoutForm from "../../../src/components/LayoutBuilderPageLayoutForm.vue";
import state from "../../mocks/state";
import Store from "../../../src/store/index";

const localVue = createLocalVue();
const store = Store(state);

localVue.use(Vuex);

describe("PageLayoutForm.vue", () => {
  const action = "foo";
  Vue.prototype.$saveUrl = action;

  const wrapper = shallowMount(PageLayoutForm, {
    propsData: {
      indexSection: 2,
      section: {
        layout: null
      }
    },
    computed: {
      undoButtonEnabled: {
        get() {
          return true;
        },
        set(value) {
          this.undoButtonEnabled = value;
        }
      },
      redoButtonEnabled: {
        get() {
          return true;
        },
        set(value) {
          this.redoButtonEnabled = value;
        }
      }
    },
    store,
    localVue
  });

  const stub = jest.fn();
  store.dispatch = stub;

  it("should render the correct form action", () => {
    expect(wrapper.element.action).toEqual(action);
  });

  describe("clicking on undo", () => {
    it("should dispatch 'undo' on the store", () => {
      wrapper
        .find(
          ".LayoutBuilderPageLayoutForm-option--undo layoutbuilderbutton-stub"
        )
        .trigger("click");
      expect(stub).toHaveBeenCalledWith("undo");
    });
  });

  describe("clicking on redo", () => {
    it("should dispatch 'redo' on the store", () => {
      wrapper
        .find(
          ".LayoutBuilderPageLayoutForm-option--redo layoutbuilderbutton-stub"
        )
        .trigger("click");
      expect(stub).toHaveBeenCalledWith("redo");
    });
  });

  it("sets the stringified value of state.sections as the value of the section input", () => {
    expect(
      wrapper.find(".LayoutBuilderPageLayoutForm-input").attributes().value
    ).toEqual(JSON.stringify(store.state.sections));
  });
});
