import cloneDeep from "clone-deep";
import actions from "../../../src/store/actions";
import state from "../../mocks/state";
import Store from "../../../src/store/index";

const store = Store(state);

describe("actions", () => {
  const data = {
    foo: "bar"
  };
  const stub = jest.fn();
  store.commit = stub;

  afterEach(() => {
    store.replaceState(cloneDeep(state));
  });

  describe("editContent()", () => {
    it("commits editContent on the store", () => {
      actions.editContent(store, data);
      expect(stub).toHaveBeenCalledWith("editContent", data);
    });

    it("commits setCurrentlyEditableContent on the store with null", () => {
      actions.editContent(store, data);
      expect(stub).toHaveBeenCalledWith("setCurrentlyEditableContent", null);
    });

    it("commits setIframeSrc on the store with null", () => {
      actions.editContent(store, data);
      expect(stub).toHaveBeenCalledWith("setIframeSrc", null);
    });

    it("commits setContentTypesOverlayVisibility on the store with false", () => {
      actions.editContent(store, data);
      expect(stub).toHaveBeenCalledWith(
        "setContentTypesOverlayVisibility",
        false
      );
    });
  });

  describe("showContentTypesOverlay()", () => {
    it("commits setCurrentlyEditableContent on the store with data", () => {
      actions.showContentTypesOverlay(store, data);
      expect(stub).toHaveBeenCalledWith("setCurrentlyEditableContent", data);
    });

    it("commits setContentTypesOverlayVisibility on the store with true", () => {
      actions.showContentTypesOverlay(store, data);
      expect(stub).toHaveBeenCalledWith(
        "setContentTypesOverlayVisibility",
        true
      );
    });
  });

  describe("closeElementsOverlay()", () => {
    it("commits setCurrentlyEditableContent on the store with null", () => {
      actions.closeElementsOverlay(store);
      expect(stub).toHaveBeenCalledWith("setCurrentlyEditableContent", null);
    });

    it("commits setContentTypesOverlayVisibility on the store with false", () => {
      actions.closeElementsOverlay(store);
      expect(stub).toHaveBeenCalledWith(
        "setContentTypesOverlayVisibility",
        false
      );
    });
  });

  describe("showIframe()", () => {
    const params = {
      indexSection: 1,
      indexSectionBlock: 0,
      slotId: "1"
    };

    it("commits setCurrentlyEditableContent on the store with the given data", () => {
      actions.showIframe(store, params);
      expect(stub).toHaveBeenCalledWith("setCurrentlyEditableContent", params);
    });

    it("commits setIframeSrc on the store with the correct editUrl", () => {
      actions.showIframe(store, params);
      expect(stub).toHaveBeenCalledWith(
        "setIframeSrc",
        store.state.elements[
          store.state.sections[params.indexSection].content[params.slotId][
            params.indexSectionBlock
          ]
        ].editUrl
      );
    });
  });
});
